==> haskell-blaze-html-0.9.1.2-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-html
version:              0.9.1.2
visibility:           public
id:                   blaze-html-0.9.1.2-42W8bO9oT0b5kevM2D91t1
key:                  blaze-html-0.9.1.2-42W8bO9oT0b5kevM2D91t1
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  8448f67e23ca785382948414e2d7d3da
exposed:              True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes

import-dirs:          /usr/lib/ghc-8.10.2/site-local/blaze-html-0.9.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/blaze-html-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/blaze-html-0.9.1.2
hs-libraries:         HSblaze-html-0.9.1.2-42W8bO9oT0b5kevM2D91t1
depends:
    base-4.14.1.0 blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7
    blaze-markup-0.8.2.7-LxYHHNtMMqd23FQvjJOkWQ bytestring-0.10.10.0
    text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html:         /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.9.1.2-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-html
version:              0.9.1.2
visibility:           public
id:                   blaze-html-0.9.1.2-C0HfhSt0P3WLbqOzNljvXh
key:                  blaze-html-0.9.1.2-C0HfhSt0P3WLbqOzNljvXh
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  97f840317436f8cc027aaf9b8a43f160
exposed:              True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes

import-dirs:          /usr/lib/ghc-8.10.3/site-local/blaze-html-0.9.1.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/blaze-html-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/blaze-html-0.9.1.2
hs-libraries:         HSblaze-html-0.9.1.2-C0HfhSt0P3WLbqOzNljvXh
depends:
    base-4.14.1.0 blaze-builder-0.4.1.0-AY5yPUQEaMfQ8f1oQxUHw
    blaze-markup-0.8.2.7-9sMS9sFEPsZ3VpOkcNgn7I bytestring-0.10.12.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html:         /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
